API docs for “spamfighter.txjsonrpc.netstring.jsonrpc.RPCFactory”

# Class s.t.n.j.RPCFactory(protocol.ServerFactory):

Part of spamfighter.txjsonrpc.netstring.jsonrpc View Source View In Hierarchy

Undocumented

Method | __init__ | Undocumented
Method | buildProtocol | Undocumented
Method | putSubHandler | Undocumented
Method | addIntrospection | Undocumented

def __init__(self, rpcClass, maxLength=1024): (source)
Undocumented
def buildProtocol(self, addr): (source)
Undocumented
def putSubHandler(self, name, klass, args=(), kws={}): (source)
Undocumented
def addIntrospection(self): (source)
Undocumented